Struct rscript::ScriptManager [−][src]
pub struct ScriptManager { /* fields omitted */ }Expand description
ScriptManager holds all the scripts found, it can be constructed with ScriptManager::default
Initially its empty, to populate it, we can use one of the methods to add scripts, currently only ScriptManager::add_scripts_by_path is provided
Implementations
Look for scripts in the specified folder The script manager will send a Message::Greeting for every script found and the scripts must respond with ScriptInfo
Trigger a hook All scripts that are active and that are listening for this particular hook will receive it
Mutable list of current scripts, useful for activating/deactivating a script